import { Modal, ModalService, DialogService, LoadingService } from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { FileUpload } from '@/services/FileUpload';
import { LoginDialogService } from '@/services/LoginDialogService';
import { LoginAlertService } from '@/services/LoginAlertService';
import Messages from '@/services/Messages';

export class PrivacyPolicyClientController {
    private modalPrivacyPolicyClient!: Modal;

    private doomIframe: any;

    private docSrc = '';

    private noFileSelected = true;

    private saveLoadingModal = false;

    public deleteModalLocker = false;

    public denieDeleteButton = true;

    public async createModalPrivacyPolicyClient() {
        try {
			LoadingService.show();
            const getPrivacyPolicyClient = await Http.get('/findPrivacyPolicyClient');
			this.docSrc = getPrivacyPolicyClient.data.dataset.findPrivacyPolicyClient[0].pdfPath;
			this.denieDeleteButton = getPrivacyPolicyClient.data.dataset.findPrivacyPolicyClient[0].documentDefault;
			this.modalPrivacyPolicyClient = await ModalService.createFromJson('pages/politicaPrivacidadeModal/politicaPrivacidadeClienteModal', true);
			this.setDocSrc();
			LoadingService.hide();
		} catch (e) {
			LoadingService.hide();
            LoginDialogService.showErrorBackend(e);
        }
    }

    public setDocSrc() {
        const doomIframe = document.getElementById('iframeClientDocId') as HTMLIFrameElement;
        doomIframe.src = this.docSrc;
    }

    public destroyModalPrivacyPolicyClient() {
        this.modalPrivacyPolicyClient.destroy();
    }

    public openModalPrivacyPolicyClient() {
        this.modalPrivacyPolicyClient.show();
    }

    public closeModalPrivacyPolicyClient() {
        this.modalPrivacyPolicyClient.hide();
        this.noFileSelected = true;
    }

    public async deleteCurrentFile() {
        this.deleteModalLocker = false;
        DialogService.show({
            name: 'delete_dialog',
            type: 'error',
            title: 'Excluir Política de Privacidade',
            text: Messages.DELETE_DEFAULT,
            buttons: [
                { name: 'yesBtn', component: 'ZdButton', label: 'Sim', events: this.dialogContinue, outline: true },
                { name: 'noBtn', component: 'ZdButton', label: 'Não', events: this.dialogHide },
            ],
        });
    }

    private dialogContinue: any = {
        click: async () => {
            if (!this.deleteModalLocker) {
                this.deleteModalLocker = true;
                try {
					LoadingService.show();
                    const aux = await Http.delete('/removePrivacyPolicyClient');
                    LoginAlertService.defaultDeleteSuccessAlert();
                    this.docSrc = aux.data.dataset.removePrivacyPolicyClient[0].pdfPath;
                    await this.setDocSrc();
                    await DialogService.hide();
                    this.denieDeleteButton = true;
					LoadingService.hide();
                } catch (e) {
					LoadingService.hide();
                    LoginDialogService.showErrorBackend(e);
                    this.deleteModalLocker = false;
                }
            }
        },
    };

    private dialogHide: any = {
        click: () => DialogService.hide(),
    };

    public changeFileInput(params: any) {
        if (params.component.value.length > 0) {
            this.noFileSelected = false;
        } else {
            this.noFileSelected = true;
        }
    }

    public async saveModalPrivacyPolicyClient() {
        this.saveLoadingModal = true;
        this.noFileSelected = true;
        const fileInput: any = Metadata.getInstance('fileInputModalPrivacyPolicyClient');
        const sendObject = await FileUpload.buildFileSendObject(fileInput.value[0]);
        if (fileInput.value[0].type === 'application/pdf' && fileInput.value[0].size < 50000000) {
            try {
                const newDocSrc = await Http.post('/uploadPrivacyPolicyClient/save', {
                    dataset: [
                        {
                            UPLOAD_PRIVACY_POLICY_CLIENT:
                            [
                                sendObject,
                            ],
                        },
                    ],
                    requestType: 'DataSet',
                });
                this.docSrc = newDocSrc.data[0].pdfPath;
                await this.setDocSrc();
                this.denieDeleteButton = newDocSrc.data[0].documentDefault;
                this.modalPrivacyPolicyClient.hide();
            } catch (e) {
                LoginDialogService.showErrorBackend(e);
                this.noFileSelected = false;
            }
            LoginAlertService.defaultSaveSuccessAlert();
            this.saveLoadingModal = false;
        } else {
            LoginAlertService.customErrorAlert(Messages.ERROR_PDF);
            this.saveLoadingModal = false;
            this.noFileSelected = false;
        }
    }
}
